@@ -4,7 +4,7 @@
 #' multivariate VAR time series using penalized least squares methods,
 #' such as ENET, SCAD or MC+.
 #'
-#' @usage fitVAR(data, p = 1, penalty = "ENET", method = "cv", ...)
+#' @usage fit_var(data, p = 1, penalty = "ENET", method = "cv", ...)
 #'
 #' @param data the data from the time series: variables in columns and
 #' observations in rows
@@ -28,9 +28,7 @@
 #' validation (default = 100);
 #' \code{leaveOut}: in the time slice validation leave out the
 #' last \code{leaveOutLast} observations (default = 15);
-#' \code{horizon}: the horizon to use for estimating mse/mae (default = 1);
-#' \code{picasso}: use picasso package for estimation (only available
-#' for \code{penalty = "SCAD"} and \code{method = "timeSlice"}).
+#' \code{horizon}: the horizon to use for estimating mse/mae (default = 1).
 #'
 #' @return \code{A} the list (of length \code{p}) of the estimated matrices
 #' of the process
@@ -40,133 +38,129 @@
 #' @return \code{residuals} the time series of the residuals
 #'
 #' @export
-fitVAR <- function(data, p = 1, penalty = "ENET", method = "cv", ...) {
+fit_var <- function(data, p = 1, penalty = "ENET", method = "cv", ...) {
+
+  checkmate::assert_choice(penalty, c("ENET", "SCAD", "MCP"))
+  checkmate::assert_count(p, positive = TRUE)
+  checkmate::assert_choice(method, c("cv", "timeSlice"))
+
   opt <- list(...)
 
   # convert data to matrix
   if (!is.matrix(data)) {
     data <- as.matrix(data)
   }
-
   cnames <- colnames(data)
 
+  opt$method <- method
   if (method == "cv") {
-
     # use CV to find lambda
-    opt$method <- "cv"
-    out <- cvVAR(data, p, penalty, opt)
-  } else if (method == "timeSlice") {
-
-    # use timeslice to find lambda
-    opt$method <- "timeSlice"
-    out <- timeSliceVAR(data, p, penalty, opt)
+    out <- cv_var(data, p, penalty, opt)
   } else {
-
-    # error: unknown method
-    stop("Unknown method. Possible values are \"cv\" or \"timeSlice\"")
+    # use timeslice to find lambda
+    out <- time_slice_var(data, p, penalty, opt)
   }
 
   # Add the names of the variables to the matrices
   if (!is.null(cnames)) {
-    for (k in 1:length(out$A)) {
+    for (k in seq_along(out$A)) {
       colnames(out$A[[k]]) <- cnames
       rownames(out$A[[k]]) <- cnames
     }
   }
 
-  return(out)
+  out
 }
 
-cvVAR <- function(data, p, penalty = "ENET", opt = NULL) {
+cv_var <- function(data, p, penalty = "ENET", opt = NULL) {
   nc <- ncol(data)
   nr <- nrow(data)
 
-  picasso <- ifelse(!is.null(opt$picasso), opt$picasso, FALSE)
   threshold <- ifelse(!is.null(opt$threshold), opt$threshold, FALSE)
-
-  threshold_type <- ifelse(!is.null(opt$threshold_type),
-    opt$threshold_type, "soft"
+  threshold_type <- ifelse(
+    !is.null(opt$threshold_type),
+    opt$threshold_type,
+    "soft"
   )
 
   return_fit <- ifelse(!is.null(opt$return_fit), opt$return_fit, FALSE)
 
-  if (picasso) {
-    stop("picasso available only with timeSlice method.")
-  }
   # transform the dataset
-  tr_dt <- transformData(data, p, opt)
+  tr_dt <- transform_data(data, p, opt)
 
   if (penalty == "ENET") {
-
     # fit the ENET model
     t <- Sys.time()
-    fit <- cvVAR_ENET(tr_dt$X, tr_dt$y, nvar = nc, opt)
+    fit <- cv_var_enet(tr_dt$X, tr_dt$y, nvar = nc, opt)
     elapsed <- Sys.time() - t
 
     # extract what is needed
     lambda <- ifelse(is.null(opt$lambda), "lambda.min", opt$lambda)
 
     # extract the coefficients and reshape the matrix
-    Avector <- stats::coef(fit, s = lambda)
-    A <- matrix(Avector[2:length(Avector)],
-      nrow = nc, ncol = nc * p,
+    a_vector <- stats::coef(fit, s = lambda)
+    a <- matrix(
+      a_vector[2:length(a_vector)],
+      nrow = nc,
+      ncol = nc * p,
       byrow = TRUE
     )
 
     mse <- min(fit$cvm)
   } else if (penalty == "SCAD") {
-
     # convert from sparse matrix to std matrix (SCAD does not work with sparse
     # matrices)
     tr_dt$X <- as.matrix(tr_dt$X)
 
     # fit the SCAD model
     t <- Sys.time()
-    fit <- cvVAR_SCAD(tr_dt$X, tr_dt$y, opt)
+    fit <- cv_var_scad(tr_dt$X, tr_dt$y, opt)
     elapsed <- Sys.time() - t
 
     # extract the coefficients and reshape the matrix
-    Avector <- stats::coef(fit, s = "lambda.min")
-    A <- matrix(Avector[2:length(Avector)],
-      nrow = nc, ncol = nc * p,
+    a_vector <- stats::coef(fit, s = "lambda.min")
+    a <- matrix(
+      a_vector[2:length(a_vector)],
+      nrow = nc,
+      ncol = nc * p,
       byrow = TRUE
     )
     mse <- min(fit$cve)
   } else if (penalty == "MCP") {
-
     # convert from sparse matrix to std matrix (MCP does not work with sparse
     # matrices)
     tr_dt$X <- as.matrix(tr_dt$X)
 
     # fit the MCP model
     t <- Sys.time()
-    fit <- cvVAR_SCAD(tr_dt$X, tr_dt$y, opt)
+    fit <- cv_var_mcp(tr_dt$X, tr_dt$y, opt)
     elapsed <- Sys.time() - t
 
     # extract the coefficients and reshape the matrix
-    Avector <- stats::coef(fit, s = "lambda.min")
-    A <- matrix(Avector[2:length(Avector)],
-      nrow = nc, ncol = nc * p,
+    a_vector <- stats::coef(fit, s = "lambda.min")
+    a <- matrix(
+      a_vector[2:length(a_vector)],
+      nrow = nc,
+      ncol = nc * p,
       byrow = TRUE
     )
     mse <- min(fit$cve)
   } else {
-
     # Unknown penalty error
-    stop("Unkown penalty. Available penalties are: ENET, SCAD, MCP.")
+    stop("Unknown penalty. Available penalties are: ENET, SCAD, MCP.")
   }
 
   # If threshold = TRUE then set to zero all the entries that are smaller than
   # the threshold
-  if (threshold == TRUE) {
-    A <- applyThreshold(A, nr, nc, p, type = threshold_type)
+  if (threshold) {
+    a <- apply_threshold(a, nr, nc, p, type = threshold_type)
   }
 
   # Get back the list of VAR matrices (of length p)
-  A <- splitMatrix(A, p)
+  a <- split_matrix(a, p)
 
   # Now that we have the matrices compute the residuals
-  res <- computeResiduals(tr_dt$series, A)
+  res <- compute_residuals(tr_dt$series, a)
 
   # To extract the sd of mse
   if (penalty == "ENET") {
@@ -180,10 +174,10 @@ cvVAR <- function(data, p, penalty = "ENET", opt = NULL) {
   # Create the output
   output <- list()
   output$mu <- tr_dt$mu
-  output$A <- A
+  output$A <- a
 
   # Do you want the fit?
-  if (return_fit == TRUE) {
+  if (return_fit) {
     output$fit <- fit
   }
 
@@ -197,16 +191,16 @@ cvVAR <- function(data, p, penalty = "ENET", opt = NULL) {
   output$residuals <- res
 
   # Variance/Covariance estimation
-  output$sigma <- estimateCovariance(res)
+  output$sigma <- estimate_covariance(res)
 
   output$penalty <- penalty
   output$method <- "cv"
   attr(output, "class") <- "var"
   attr(output, "type") <- "fit"
-  return(output)
+  output
 }
 
-cvVAR_ENET <- function(X, y, nvar, opt) {
+cv_var_enet <- function(x, y, nvar, opt) {
   a <- ifelse(is.null(opt$alpha), 1, opt$alpha)
   nl <- ifelse(is.null(opt$nlambda), 100, opt$nlambda)
   tm <- ifelse(is.null(opt$type.measure), "mse", opt$type.measure)
@@ -215,140 +209,132 @@ cvVAR_ENET <- function(X, y, nvar, opt) {
   ncores <- ifelse(is.null(opt$ncores), 1, opt$ncores)
 
   # Vector of lambdas to work on
+  lambdas_list <- c(0)
   if (!is.null(opt$lambdas_list)) {
     lambdas_list <- opt$lambdas_list
-  } else {
-    lambdas_list <- c(0)
   }
 
   # Assign ids to the CV-folds (useful for replication of results)
-  if (is.null(opt$folds_ids)) {
-    folds_ids <- numeric(0)
-  } else {
-    nr <- nrow(X)
+  folds_ids <- numeric(0)
+  if (!is.null(opt$folds_ids)) {
+    nr <- nrow(x)
     folds_ids <- rep(sort(rep(seq(nf), length.out = nr / nvar)), nvar)
   }
 
-  if (parall == TRUE) {
+  if (parall) {
     if (ncores < 1) {
       stop("The number of cores must be > 1")
     } else {
       cl <- doParallel::registerDoParallel(cores = ncores)
-
-      if (length(folds_ids) == 0) {
-        if (length(lambdas_list) < 2) {
-          cvfit <- glmnet::cv.glmnet(X, y,
-            alpha = a, nlambda = nl,
-            type.measure = tm, nfolds = nf,
-            parallel = TRUE, standardize = FALSE
-          )
-        } else {
-          cvfit <- glmnet::cv.glmnet(X, y,
-            alpha = a, lambda = lambdas_list,
-            type.measure = tm, nfolds = nf,
-            parallel = TRUE, standardize = FALSE
-          )
-        }
-      } else {
-        if (length(lambdas_list) < 2) {
-          cvfit <- glmnet::cv.glmnet(X, y,
-            alpha = a, nlambda = nl,
-            type.measure = tm, foldid = folds_ids,
-            parallel = TRUE, standardize = FALSE
-          )
-        } else {
-          cvfit <- glmnet::cv.glmnet(X, y,
-            alpha = a, lambda = lambdas_list,
-            type.measure = tm, foldid = folds_ids,
-            parallel = TRUE, standardize = FALSE
-          )
-        }
-      }
-    }
-  } else {
-    if (length(folds_ids) == 0) {
-      if (length(lambdas_list) < 2) {
-        cvfit <- glmnet::cv.glmnet(X, y,
-          alpha = a, nlambda = nl,
-          type.measure = tm, nfolds = nf,
-          parallel = FALSE, standardize = FALSE
-        )
-      } else {
-        cvfit <- glmnet::cv.glmnet(X, y,
-          alpha = a, lambda = lambdas_list,
-          type.measure = tm, nfolds = nf,
-          parallel = FALSE, standardize = FALSE
-        )
-      }
-    } else {
-      if (length(lambdas_list) < 2) {
-        cvfit <- glmnet::cv.glmnet(X, y,
-          alpha = a, nlambda = nl,
-          type.measure = tm, foldid = folds_ids,
-          parallel = FALSE, standardize = FALSE
-        )
-      } else {
-        cvfit <- glmnet::cv.glmnet(X, y,
-          alpha = a, lambda = lambdas_list,
-          type.measure = tm, foldid = folds_ids,
-          parallel = FALSE, standardize = FALSE
-        )
-      }
     }
   }
-
-  return(cvfit)
-}
-
-cvVAR_SCAD <- function(X, y, opt) {
-  e <- ifelse(is.null(opt$eps), 0.01, opt$eps)
-  nf <- ifelse(is.null(opt$nfolds), 10, opt$nfolds)
-  parall <- ifelse(is.null(opt$parallel), FALSE, opt$parallel)
-  ncores <- ifelse(is.null(opt$ncores), 1, opt$ncores)
-  picasso <- ifelse(is.null(opt$picasso), FALSE, TRUE)
-
-  if (!picasso) {
-    if (parall == TRUE) {
-      if (ncores < 1) {
-        stop("The number of cores must be > 1")
-      } else {
-        cl <- parallel::makeCluster(ncores)
-        cvfit <- ncvreg::cv.ncvreg(X, y,
-          nfolds = nf, penalty = "SCAD",
-          eps = e, cluster = cl
-        )
-        parallel::stopCluster(cl)
-      }
+  if (length(folds_ids) == 0) {
+    if (length(lambdas_list) < 2) {
+      cvfit <- glmnet::cv.glmnet(
+        x,
+        y,
+        alpha = a,
+        nlambda = nl,
+        type.measure = tm,
+        nfolds = nf,
+        parallel = parall,
+        standardize = FALSE
+      )
     } else {
-      cvfit <- ncvreg::cv.ncvreg(X, y, nfolds = nf, penalty = "SCAD", eps = e)
+      cvfit <- glmnet::cv.glmnet(
+        x,
+        y,
+        alpha = a,
+        lambda = lambdas_list,
+        type.measure = tm,
+        nfolds = nf,
+        parallel = parall,
+        standardize = FALSE
+      )
     }
   } else {
-    cvfit <- picasso::picasso(X, y, method = "scad")
+    if (length(lambdas_list) < 2) {
+      cvfit <- glmnet::cv.glmnet(
+        x,
+        y,
+        alpha = a,
+        nlambda = nl,
+        type.measure = tm,
+        foldid = folds_ids,
+        parallel = parall,
+        standardize = FALSE
+      )
+    } else {
+      cvfit <- glmnet::cv.glmnet(
+        x,
+        y,
+        alpha = a,
+        lambda = lambdas_list,
+        type.measure = tm,
+        foldid = folds_ids,
+        parallel = parall,
+        standardize = FALSE
+      )
+    }
+  }
+  if (parall) {
+    parallel::stopCluster(cl)
   }
 
-  return(cvfit)
+  cvfit
 }
 
-cvVAR_MCP <- function(X, y, opt) {
+cv_var_scad <- function(x, y, opt) {
   e <- ifelse(is.null(opt$eps), 0.01, opt$eps)
   nf <- ifelse(is.null(opt$nfolds), 10, opt$nfolds)
   parall <- ifelse(is.null(opt$parallel), FALSE, opt$parallel)
   ncores <- ifelse(is.null(opt$ncores), 1, opt$ncores)
 
-  if (parall == TRUE) {
+  if (parall) {
     if (ncores < 1) {
       stop("The number of cores must be > 1")
     } else {
       cl <- parallel::makeCluster(ncores)
-      cvfit <- ncvreg::cv.ncvreg(X, y,
-        nfolds = nf, penalty = "MCP",
-        eps = e, cluster = cl
+      cvfit <- ncvreg::cv.ncvreg(
+        x,
+        y,
+        nfolds = nf,
+        penalty = "SCAD",
+        eps = e,
+        cluster = cl
       )
       parallel::stopCluster(cl)
     }
   } else {
-    cvfit <- ncvreg::cv.ncvreg(X, y, nfolds = nf, penalty = "MCP", eps = e)
+    cvfit <- ncvreg::cv.ncvreg(x, y, nfolds = nf, penalty = "SCAD", eps = e)
+  }
+  cvfit
+}
+
+cv_var_mcp <- function(x, y, opt) {
+  e <- ifelse(is.null(opt$eps), 0.01, opt$eps)
+  nf <- ifelse(is.null(opt$nfolds), 10, opt$nfolds)
+  parall <- ifelse(is.null(opt$parallel), FALSE, opt$parallel)
+  ncores <- ifelse(is.null(opt$ncores), 1, opt$ncores)
+
+  if (parall) {
+    if (ncores < 1) {
+      stop("The number of cores must be > 1")
+    } else {
+      cl <- parallel::makeCluster(ncores)
+      cvfit <- ncvreg::cv.ncvreg(
+        x,
+        y,
+        nfolds = nf,
+        penalty = "MCP",
+        eps = e,
+        cluster = cl
+      )
+      parallel::stopCluster(cl)
+    }
+  } else {
+    cvfit <- ncvreg::cv.ncvreg(x, y, nfolds = nf, penalty = "MCP", eps = e)
   }
 
-  return(cvfit)
+  cvfit
 }
